---
id: index
title: Usage Guides Index
sidebar_label: Usage Guides Index
---

# Usage Guides

The Usage Guides section provides practical guidance on how to correctly use Redux in real-world applications, including project setup and architecture, patterns, practices, and techniques.

:::info Prerequisites

The pages in this category assume you understand the core Redux terms and concepts explained in [the "Redux Fundamentals" tutorial](../tutorials/fundamentals/part-1-overview.md), including actions, reducers, stores, immutability, React-Redux, and async logic.

:::

## Setup and Organization

This section covers information on how to set up and organize Redux-based projects.

- [Configuring Your Store](ConfiguringYourStore.md)
- [Code Splitting](CodeSplitting.md)
- [Server Rendering](ServerRendering.md)
- [Isolating Redux Sub-Apps](IsolatingSubapps.md)

## Code Quality

This section provides information on tools and techniques used to improve the quality of your Redux code.

- [Usage with TypeScript](UsageWithTypescript.md)
- [Writing Tests](WritingTests.md)
- [Troubleshooting](Troubleshooting.md)

## Redux Logic and Patterns

This section provides information about typical Redux patterns and approaches for writing different kinds of Redux logic.

- [Structuring Reducers](structuring-reducers/StructuringReducers.md)
- [Reducing Boilerplate](ReducingBoilerplate.md)
- [Deriving Data with Selectors](../usage/deriving-data-selectors.md)
- [Implementing Undo History](ImplementingUndoHistory.md)
